#!/bin/sh
export PATH='/build/haskell-doctest-discover/src/doctest-discover-04b6b1f9fa93518e49d7a95052e6efc2d2d2dabe/dist/build/doctest-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/build/haskell-doctest-discover/src/doctest-discover-04b6b1f9fa93518e49d7a95052e6efc2d2d2dabe/dist/build/doctest-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:               doctest-discover
version:            0.2.0.0
visibility:         public
id:                 doctest-discover-0.2.0.0-Ddi7aulVKEq8Xcpf0mlzFg
key:                doctest-discover-0.2.0.0-Ddi7aulVKEq8Xcpf0mlzFg
license:            LicenseRef-PublicDomain
maintainer:         karun012@gmail.com
author:             Karun Ramakrishnan
homepage:           http://github.com/karun012/doctest-discover
synopsis:           Easy way to run doctests via cabal
description:
    doctest-discover provides an easy way to run doctests via cabal

category:           Testing
abi:                6f78e70309fb6303857b6a05d0c7aa3c
exposed:            True
data-dir:           /usr/share/haskell-doctest-discover
depends:
    aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W base-4.18.2.1
    bytestring-0.11.5.3 directory-1.3.8.5
    doctest-0.22.4-75Tg6L8Bu5SIHZSrHeao7E filepath-1.4.300.1

haddock-interfaces:
    /usr/share/doc/haskell-doctest-discover/html/doctest-discover.haddock

haddock-html:       /usr/share/doc/haskell-doctest-discover/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

